pygeodesy.datums.Transform

Package pygeodesy :: Module datums :: Class Transform |
[frames] | no frames]

# Class Transform

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                          Transform

Known Subclasses:
  - trf.TransformXform

Helmert datum transformation.

See Also: TransformXform.

Instance Methods
__eq__(self, other) Compare this and an other transform. |
__hash__(self) hash(x) |
__init__(self, name='', tx=0, ty=0, tz=0, s=0, sx=0, sy=0, sz=0) New Transform. |
__iter__(self) Yield the initial attribute values, in order. |
__matmul__(self, point) Transform an ellipsoidal `point` with this Helmert. |
__neg__(self) |
inverse(self, **name) Return the inverse of this transform. |
items(self, inverse=False) Yield the initial attributes, each as 2-tuple `(name, value)`. |
toStr(self, prec=5, fmt='g', **sep_name) Return this transform as a string. |
transform(self, x, y, z, inverse=False, **Vector_and_kwds) Transform a (cartesian) position, forward or inverse. |
Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| rx = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| ry = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| rz = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| s = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| s1 = `1.0`
| sx = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| sy = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| sz = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| tx = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| ty = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.
| tz = `0.0` Get the complete integral of the second kind `E(k)` (`float`), defined.

Properties
| isunity Is this a `unity, identity` transform (`bool`), like WGS84 with translation, scale and rotation all zero?
Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __eq__ (self, other) (Equality operator) |
Compare this and an other transform. Arguments: `other` - The other transform (Transform). Returns: `True` if equal, `False` otherwise.

### __hash__ (self) (Hashing function) |
hash(x) Overrides: object.__hash__ (inherited documentation)

### __init__ (self, name='', tx=0, ty=0, tz=0, s=0, sx=0, sy=0, sz=0) (Constructor) |
New Transform. Arguments: `name` - Optional, unique name (`str`). `tx` - X translation (`meter`). `ty` - Y translation (`meter`). `tz` - Z translation (`meter`). `s` - Scale (`float`), ppm. `sx` - X rotation (`arc-seconds`). `sy` - Y rotation (`arc-seconds`). `sz` - Z rotation (`arc-seconds`). Raises: `NameError` - Transform with that `name` already exists. Overrides: object.__init__

### __matmul__ (self, point) |
Transform an ellipsoidal `point` with this Helmert. Returns: A transformed copy of `point`. Raises: `TypeError` - Invalid `point`. Overrides: named._Named.__matmul__ See Also: Method `point.toTransform`.

### inverse (self, **name) |
Return the inverse of this transform. Arguments: `name` - Optional, unique name (`str`). Returns: Inverse (Transform), unregistered.

### items (self, inverse=False) |
Yield the initial attributes, each as 2-tuple `(name, value)`. Arguments: `inverse` - If `True`, negate the values (`bool`).

### toStr (self, prec=5, fmt='g', **sep_name) |
Return this transform as a string. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `fmt` - Optional `float` format (`letter`). `sep_name` - Optional `name=NN` (`str`) or `None` to exclude this transform's name and separater `sep=", "` to join the items (`str`). Returns: Transform attributes (`str`). Overrides: named._Named.toStr

### transform (self, x, y, z, inverse=False, **Vector_and_kwds) |
Transform a (cartesian) position, forward or inverse. Arguments: `x` - X coordinate (`meter`). `y` - Y coordinate (`meter`). `z` - Z coordinate (`meter`). `inverse` - If `True`, apply the inverse transform (`bool`). `Vector_and_kwds` - An optional, (3-D) `Vector=None` or cartesian class and additional `Vector` keyword arguments to return the transformed position. Returns: The transformed position (Vector3Tuple`(x, y, z)`) unless some `Vector_and_kwds` are specified.

Property Details

### isunity Is this a `unity, identity` transform (`bool`), like WGS84 with translation, scale and rotation all zero? Get method: isunity(self) - Is this a `unity, identity` transform (`bool`), like WGS84 with translation, scale and rotation all zero? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.